# llama-rl

[![PyPI - Version](https://img.shields.io/pypi/v/llama-rl.svg)](https://pypi.org/project/llama-rl)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/llama-rl.svg)](https://pypi.org/project/llama-rl)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install llama-rl
```

## License

`llama-rl` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
